"""UI pages for the injection server."""

from mcp_server_llmling.ui.pages.dashboard import DashboardPage
from mcp_server_llmling.ui.pages.resources import ResourcesPage
from mcp_server_llmling.ui.pages.tools import ToolsPage

__all__ = ["DashboardPage", "ResourcesPage", "ToolsPage"]
